@@ -164,8 +164,8 @@ class ServiceLauncherTest(ServiceTestBase):
         # Skip ps header
         f.readline()
 
-        processes = [tuple(int(p) for p in l.strip().split()[:2])
-                     for l in f]
+        processes = [tuple(int(p) for p in line.strip().split()[:2])
+                     for line in f]
         return [p for p, pp in processes if pp == self.pid]
 
     def test_killed_worker_recover(self):
@@ -476,7 +476,6 @@ class ProcessLauncherTest(base.ServiceBaseTestCase):
             m.assert_called_once_with(signal.SIGTERM, 'test')
         signal_handler.clear()
 
-    @mock.patch('sys.version_info', (3, 5))
     def test_setup_signal_interruption_no_select_poll(self):
         # NOTE(claudiub): SignalHandler is a singleton, which means that it
         # might already be initialized. We need to clear to clear the cache
@@ -490,7 +489,6 @@ class ProcessLauncherTest(base.ServiceBaseTestCase):
         self.assertFalse(
             signal_handler._SignalHandler__force_interrupt_on_signal)
 
-    @mock.patch('sys.version_info', (3, 5))
     def test_setup_signal_interruption_select_poll(self):
         # NOTE(claudiub): SignalHandler is a singleton, which means that it
         # might already be initialized. We need to clear to clear the cache
